@@ -16,3 +16,15 @@ class ArgumentWrongTypeException(WebDriverException):
 
 class WebDriverIsNoneException(WebDriverException):
     pass
+
+
+class WebRunnerExecuteException(WebDriverException):
+    pass
+
+
+class WebRunnerJsonException(WebDriverException):
+    pass
+
+
+class AssertException(WebDriverException):
+    pass
